@@ -518,8 +518,8 @@ class ThesaurusMergeEditForm(DialogAddForm):
     layout = getLayoutTemplate()
     parent_interface = IThesaurus
 
-    fields = field.Fields(IThesaurusUpdaterConfiguration).select('clear') + \
-             field.Fields(IThesaurusUpdaterConfiguration).omit('name', 'clear')
+    fields = field.Fields(IThesaurusUpdaterConfiguration).select('clear', 'conflict_suffix') + \
+             field.Fields(IThesaurusUpdaterConfiguration).omit('name', 'clear', 'conflict_suffix')
     fields['language'].widgetFactory = ThesaurusAutomaticSelectWidgetFactory
     fields['encoding'].widgetFactory = ThesaurusAutomaticSelectWidgetFactory
 
